<?php

/**
 * Enqueue scripts.
 */
function nesiapress_enqueue_scripts() {
	$theme = wp_get_theme();

	// Import fontawesome css file
	wp_enqueue_style( 'nesiapress-fontawesome-style', get_template_directory_uri() . '/assets/fontawesome/css/all.css', array(), '5.15.3');

	// Import theme style.css file
	wp_enqueue_style( 'nesiapress-style', get_stylesheet_uri(), array(), $theme->get( 'Version' ));

	// Import base theme style.css file
	wp_enqueue_style( 'nesiapress-base-style', get_template_directory_uri() . '/assets/css/style.css', array( 'nesiapress-style' ), $theme->get( 'Version' ));

	// Import fontawesome js file
	wp_enqueue_script( 'nesiapress-fontawesome', get_template_directory_uri() . '/assets/fontawesome/js/all.js', array( 'jquery' ), '5.15.3', true );

	// Import fontawesome conflict detection js file
	wp_enqueue_script( 'nesiapress-fontawesome-conflic-detection', get_template_directory_uri() . '/assets/fontawesome/js/conflict-detection.js', array( 'jquery' ), '5.15.3', true );

	// Import mobile menu button js file
	wp_enqueue_script( 'nesiapress-menu-button', get_template_directory_uri() . '/assets/js/functions.js', array( 'jquery' ), '20210601', true );

	wp_localize_script(
		'nesiapress-menu-button',
		'nesiapressReader',
		array(
			'expand'   => __( 'expand child menu', 'nesiapress' ),
			'collapse' => __( 'collapse child menu', 'nesiapress' ),
		)
	);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'nesiapress_enqueue_scripts' );

/**
 * Register widget
 */
function nesiapress_widgets_init() {
	register_sidebar(
		array(
			'name'          => __( 'Sidebar Widget', 'nesiapress' ),
			'id'            => 'sidebar-1',
			'description'   => __( 'Add widgets here to appear in your sidebar.', 'nesiapress' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	/*
	* Register footer widget
	*
	* @since 1.0.71
	*/
	register_sidebar(
		array(
			'name'          => __( 'Footer Widget', 'nesiapress' ),
			'id'            => 'sidebar-2',
			'description'   => __( 'Add widgets here to appear in your footer.', 'nesiapress' ),
			'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="footer-widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'nesiapress_widgets_init' );

/**
 * Theme setup.
 */
function nesiapress_setup() {

	// Register navigation menus uses wp_nav_menu in two places.
	register_nav_menus(
		array(
			'primary' => __( 'Primary Menu', 'nesiapress' ),
			'footer'   => __( 'Footer Menu', 'nesiapress' ),
		)
	);

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'script',
			'style',
			'navigation-widgets',
		)
	);

	/*
	* Enable support for Post Formats.
	*
	* See: https://wordpress.org/support/article/post-formats/
	*
	* @since 1.0.7
	*/
	add_theme_support(
		'post-formats',
		array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
			'gallery',
			'status',
			'audio',
			'chat',
		)
	);

	/*
	* Set up the WordPress core custom background feature.
	*
	* @since 1.0.7
	*/
	add_theme_support(
		'custom-background',
		apply_filters(
			'nesiapress_custom_background_args',
			array(
				'default-color' => 'f3f4f6',
				'default-image' => '',
			)
		)
	);

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 * 
	 * @since 1.0.7
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
			'header-text' => array( 'site-title', 'site-description' )
		)
	);

	// Let WordPress manage the document title.
	add_theme_support( 'title-tag' );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Responsive embeds
	add_theme_support( "responsive-embeds" );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Adding Thumbnail basic support.
	add_theme_support( 'post-thumbnails' );

	// Image size
	set_post_thumbnail_size( 1020, 623, true );

	// Block editor.
	add_theme_support( 'align-wide' );

	add_theme_support( 'wp-block-styles' );

	add_theme_support( 'editor-styles' );
	add_editor_style();
}

add_action( 'after_setup_theme', 'nesiapress_setup' );

/**
 * Adds option 'li_class' to 'wp_nav_menu'.
 *
 * @param string  $classes String of classes.
 * @param mixed   $item The curren item.
 * @param WP_Term $args Holds the nav menu arguments.
 *
 * @return array
 */
function nesiapress_nav_menu_add_li_class( $classes, $item, $args, $depth ) {
	if ( isset( $args->li_class ) ) {
		$classes[] = $args->li_class;
	}

	if ( isset( $args->{"li_class_$depth"} ) ) {
		$classes[] = $args->{"li_class_$depth"};
	}

	return $classes;
}

add_filter( 'nav_menu_css_class', 'nesiapress_nav_menu_add_li_class', 10, 4 );

/**
 * Adds option 'submenu_class' to 'wp_nav_menu'.
 *
 * @param string  $classes String of classes.
 * @param mixed   $item The curren item.
 * @param WP_Term $args Holds the nav menu arguments.
 *
 * @return array
 */
function nesiapress_nav_menu_add_submenu_class( $classes, $args, $depth ) {
	if ( isset( $args->submenu_class ) ) {
		$classes[] = $args->submenu_class;
	}

	if ( isset( $args->{"submenu_class_$depth"} ) ) {
		$classes[] = $args->{"submenu_class_$depth"};
	}

	return $classes;
}

add_filter( 'nav_menu_submenu_css_class', 'nesiapress_nav_menu_add_submenu_class', 10, 3 );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function nesiapress_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nesiapress_content_width', 640 );
}
add_action( 'after_setup_theme', 'nesiapress_content_width', 0 );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/components/custom-header.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/components/customizer.php';

/**
 * Custom template tags for NesiaPress theme.
 */
require get_template_directory() . '/inc/components/template-tags.php';

/**
 * Load WooCommerce compatibility file for NesiaPress theme.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/components/woocommerce.php';
}

/**
 * NesiaPress theme hook functions
 */
require get_template_directory() . '/inc/hook/header-hook.php';
require get_template_directory() . '/inc/hook/content-hook.php';
require get_template_directory() . '/inc/hook/content-col-hook.php';
require get_template_directory() . '/inc/hook/footer-widget-hook.php';
require get_template_directory() . '/inc/hook/footer-hook.php';