<?php
/**
 * Template part for displaying a message that posts cannot be found
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 * 
 * @since 1.0.0
 *
 * @package nesiapress
 */

?>

<div class="no-results not-found">
	<header class="page-header">
		<?php if ( is_search() ) : ?>

			<h1 class="page-title">
				<?php
				printf(
					/* translators: %s: Search term. */
					esc_html__( 'Results for "%s"', 'nesiapress' ),
					'<span class="page-description search-term">' . esc_html( get_search_query() ) . '</span>'
				);
				?>
			</h1><!-- .page-title -->

		<?php else : ?>

			<h1 class="page-title"><?php esc_html_e( 'Nothing here', 'nesiapress' ); ?></h1>

		<?php endif; ?>
	</header><!-- .page-header -->

	<div class="entry-content">

		<?php if ( is_home() && current_user_can( 'publish_posts' ) ) : ?>

			<?php
			printf(
				'<p>' . wp_kses(
					/* translators: %s: Link to WP admin new post page. */
					__( 'Ready to publish your first post? <a href="%s">Get started here</a>.', 'nesiapress' ),
					array(
						'a' => array(
							'href' => array(),
						),
					)
				) . '</p>',
				esc_url( admin_url( 'post-new.php' ) )
			);
			?>

		<?php elseif ( is_search() ) : ?>

			<div class="no-results-text not-found-text">
				<p><?php esc_html_e( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'nesiapress' ); ?></p>
				<?php get_search_form(); ?>
			</div><!-- .no-results-text -->

		<?php else : ?>

			<div class="no-results-text not-found-text">
				<p><?php esc_html_e( 'It seems we can&rsquo;t find what you&rsquo;re looking for. Perhaps searching can help.', 'nesiapress' ); ?></p>
				<?php get_search_form(); ?>
			</div><!-- .no-results-text -->

		<?php endif; ?>
	</div><!-- .entry-content -->
</div><!-- .no-results -->
