<?php
/**
 * Template Name: Full-width Layout
 * 
 * Template Post Type: Post
 * 
 * Template part for displaying full page content in single.php
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 * 
 * @since 1.0.0
 *
 * @package nesiapress
 */

get_header();
?>

	<div class="content-full-wrapper">
		
		<div class="hero-section">
			<figure>
				<div class="image-container">
					<?php nesiapress_post_thumbnail(); ?>
				</div>
			</figure>
		</div>

		<section class="content-full">
			<?php if ( have_posts() ) :
				while ( have_posts() ) :
					the_post();

					get_template_part( 'template-parts/content', 'single-fullwidth' );

					// show author profile
					if ( post_type_supports( get_post_type( get_the_ID() ), 'author' ) && is_single() ) {
						get_template_part( 'template-parts/profile' );
					}

					// If comments are open or we have at least one comment, load up the comment template.
					if ( comments_open() || get_comments_number() ) :
						comments_template();
					endif;
				endwhile;

				the_post_navigation(
					array(
						'next_text' => '<span class="meta-nav" aria-hidden="true">' . __( 'Next Post <i class="fas fa-sw fa-sm fa-chevron-right"></i>', 'nesiapress' ) . '</span> ' .
							'<span class="screen-reader-text">' . __( 'Next post:', 'nesiapress' ) . '</span> <br/>' .
							'<span class="post-title">%title</span>',
						'prev_text' => '<span class="meta-nav" aria-hidden="true">' . __( '<i class="fas fa-sw fa-sm fa-chevron-left"></i> Previous Post', 'nesiapress' ) . '</span> ' .
							'<span class="screen-reader-text">' . __( 'Previous post:', 'nesiapress' ) . '</span> <br/>' .
							'<span class="post-title">%title</span>',
					)
				);
			endif; ?>

			<div class="related-post">
				<?php echo wp_kses_post( apply_filters( 'nesiapress', '<p>' . esc_html__( 'Related Posts', 'nesiapress' ) . '</p>' ) );?>
				<div class="grid grid-cols-1 sm:grid-cols-2 gap-6 w-full">
					<?php
					//for use in the loop, list 4 post titles related to first tag on current post
					$tags = wp_get_post_tags($post->ID);
					
					if ($tags) {
						$first_tag = $tags[0]->term_id;
						$args=array(
							'tag__in' => array($first_tag),
							'post__not_in' => array($post->ID),
							'posts_per_page'=> 4,
							'ignore_sticky_posts'=> 1
						);
						$my_query = new WP_Query($args);

						if( $my_query->have_posts() ) { ?>

						<?php while ($my_query->have_posts()) : $my_query->the_post(); ?>

							<div class="bg-white p-6">
								<?php nesiapress_post_thumbnail(); ?>

								<?php
									the_title( sprintf( '<h2 class="related-post-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
									nesiapress_posted_by();
								?>
							</div>
						
						<?php
						endwhile; }

						wp_reset_postdata();
					} ?>
				</div> <!-- .grid -->
			</div><!-- .related-post -->
		</section><!-- .content-full -->
	</div><!-- .content-full-wrapper -->

<?php
get_footer();
